---
title: "Burlington's Half-Assed Bike Infrastructure"
description: "Venting my frustrations about this city's poor bike infrastructure"
date: 2024-04-23
tags:
  - Hometown
  - Politics
  - Civics
---

This post is a little different than my usual post here, touching more on local politics, infrastructure, and issues in my home city of Burlington, Ontario, and written with some fairly poor organization of thoughts. I, however, couldn't think of another place to put this sort of long-form content (read: long rant), so it's going here for now.

## What Burlington Has

Burlington's topography and layout is important for the criticisms below, so it's worth spending a moment describing it.

Burlington is a large commuter suburb at the southern end of Lake Ontario, with Toronto about 50km to the northeast and Hamilton directly to the south and west. The city follows a broadly east-west grid structure, with 4 major north-south roads (Brant Stree, Guelph Line, Walkers Line, and Appleby Line) spaced at 2km increments. There are further north-south roads (Burloak to the far east bordering Oakville and Bronte Creek Provincial Park, and King Road and Waterdown Road further to the west) but the main portion of the city is contained by by those first four. Downtown is at the south end of Brant St. by Lake Ontario.

Through the center of the city, east-west, run both the Queen Elizabeth Way highway and a set of GO Transit tracks. Between and just north of them is a major industrial corridor that forms the boundary between the residential "North" and "South" Burlington. There are a number of other major east-west roads that will be mentioned; from south to north, they are Lakeshore Drive, New Street, Fairview Road, Harvester Road, Mainway, Upper Middle Road, and finally Dundas Street.

At the top boundary of the developed area are Dundas Street and (west of roughly Walkers Line) Highway 407ETR; all land allocation north of these is Greenbelt land and cannot be developed. 

The topography is broadly sloping down from the Niagara Escarpment in the north to Lake Ontario in the south, with the highest peak in the (developed) city in the north-west at the top of Brant Street, and the lowest points along the lakeshore.

Lastly, there are two major northeast-southwest power lines that, due to the exact positioning, criss-cross the city on a diagonal; one in North Burlington, and one in South Burlington. A multi-use path follows both.

Here is the map:

![Map of Burlington, Ontario](burlington.jpg)
*Map courtesy of the City of Burlington*

Burlington seems like a great city to feature comprehensive bike infrastructure, but unfortunately it is thoroughly half-assed. Through nearly a century of car-centric planning and development, what should be a perfectly bikeable city is instead a congested wasteland of asphalt, concrete, and single-family sprawl.

## Burlington's Bike Infrastructure: The Good

There are a few good parts, so I'd like to list those first.

1. Multi-use paths along hydro corridors. These help provide both excellent recreational trails for casual or fitness cyclists, as well as transportation for some trips, for example North Burlington -> Downtown via the Crosstown Trail (north) or South Burlington -> Downtown via the Centennial Bikeway.

2. Multi-use paths north-south. A few of these are scattered throughout various neighbourhoods, for example the Palmer Trail in Palmer (my home neighbourhood), an unnamed extension to the Centennial Bikeway in Dynes, and another unnamed trail in Downtown. These do help cyclists cut through a number of residential areas, but as we'll see later, are not very long or effective.

3. Multi-use paths along major roads. A few of these exists: Appleby Line, Walkers Line and Brant Street feature multi-use paths beside sidewalks for a signfiicant part of their northern sections, and Upper Middle features a multi-use path along its length. Lakeshore Drive features a multi-use path instead of a sidewalk on its south side, as do Harvester Street and Dundas Street.

4. Bike Lanes and sharrow indications are present everywhere. However, as I'll outline below, these aren't *really* bike infrastructure, and are at the root of what I see as the major problems with cycling in Burlington, but we'll get there.

5. Neighbourhoods are being calmed. Most neighbourhoods in the city now post a 40km/h (instead of 50km/h) speed limit, and many roads have had speed control devices added to slow drivers down, making these roads much safer for cycling.


## Burlington's Bike Infrastructure: The Bad & The Ugly

But, there are a lot of problems with bike infrastructure in the city. I'll outline what first, before getting into the why.

1. Multi-use paths are in disarray. I've been a resident of Burlington for my entire life - 36 years - and I do not remember most of the road-paralleled multi-use paths ever being repaved. Some sections are in such poor condition that they are lost to grass/weeds, are so bumpy as to put mountain bikes under strain, let alone road bikes, and others are simply haphazardly cut as an afterthought, with sharp drops at driveways or dangerous swerves needed to descend onto cross streets.

2. Multi-use paths are very limited. Except for those north-south hydro corridor and short neighbourhood paths, the remaining bike infrastructure is limited only to major roads, and not all of them.

3. Major roads are dangerous. 60+km/h speeds on wide [stroads](https://en.wikipedia.org/wiki/Stroad) with frequent, poorly-timed traffic lights is a deathtrap for bicyclists.

4. Bike lanes are, at best, bad. Painted bicycle gutters and (*shudder*) sharrows are not bike infrastructure. A painted line does not stop a two-tonne SUV driven by a distracted and impatient motorist from running you down. Worse still, in this city as in many others, bicycle lanes start and end abruptly with no rhyme or reason, forcing cyclings into sharing lanes with speeding vehicles frequently. Combined with the previous point, this makes for several extremely dangerous sections of road.

5. Highway onramps on the major roads are a deathtrap. With no approach lanes and drivers who routinely fail to signal these, it becomes a dangerous guessing game of who is going where while waiting to cross them, or braving 70+km/h speeding vehicles cutting you off.

6. There are far too many stop signs. Stop signs are the devil. They're inefficient for cyclists (unless, of course, cyclist priority and an [Idaho Stop](https://en.wikipedia.org/wiki/Idaho_stop) system is added) and actually add danger due to a cyclist having to start from zero afterwards (see below).

## What our Brilliant Government has tried to do

Really, outlining the problems above really just serves to put into context the assinine and, as stated before, half-assed measures this city and its governmnent has taken to "improve cycling", almost none of which do anything at all. I will outline 3 key case studies here.

### Bicycle Lanes No One Needed

In 2020, the city launched a project to replace 1 lane of car traffic in each direction along New Street with a bike lane, reducing the car lanes on this very busy stretch of road from 2 to 1. These were, of course, implemented in the most half-assed way possible, using paint and nothing more. Sure, a buffered bike lane is better than no buffer, but when a 1-km backlog of cars has built up, nothing is stopping them from cutting ahead through this purely-paint "infrastructure", putting everyone else at risk. And I saw this happen.

Predictably, in a car-centric sprawl city, the backlash from carbrain drivers was swift. However, it may surprise you, I agree with them. It was a poor place to put a bike lane, because the route was already serviced by a well-used multi-use path, the Centennial Bikeway, one of the few in the city! It was a pointless waste of millions of dollars that was ripped back out (read: painted over) 2 years later.

The reasons for the failure here are clear. In a bid to make a major street "bicycle-friendly", they ignored already-existing bicycle infrastructure in favour of painted bicycle gutters, inconveniencing motorists on a busy road with a solution that did nothing at all to actually protect bicyclists from the (now increased) vehicular traffic. It is a case study of a solution in need of a problem: someone wanted to get paid to paint some bike lanes, and by golly they did - twice even - when a much better solution already existed.

![New Street Bike lanes superimposed with the Centennial Bikeway](bikeway.png)

### Another Bike Lane to Nowhere

Bike lanes on Walkers Line, Guelph Line, and other places start and end abruptly. But, the fact that these lanes exist atall is a problem, because a bicycle gutter to nowhere is almost worse than nothing.

### The Most Dangerous and Pointless "Solution" to the Highway Onramps

On, the highway onramps. As I pointed out above, the design of most of them makes them incredibly dangerous to cross, not just for cyclists, but for pedestrians as well. What was the brilliant solution? Implement the most bizarre "stop here" on a bike possible. Beyold this magnificence:

![The Stupidest Bike Crossing](bikecrossing.png)

Now, for someone used to a car, it may not be too obvious why this is an utterly terrible design. Let me list the reasons:

1. Bikes are slow to get moving after a stop, which will always happen here due to the poor road design in general.
2. The more time a bike is in the path of a car (say, due to #1), the more danger they are in.
3. A crossing is more dangerous (especially with #2 and #1) than a simple merge at speed.
4. These are on hills (due to the overpass), making #1 even worse.
5. They are abrupt and small, leaving little room to maneuver into a good position to both view oncoming traffic and proceed.
6. They are placed so close to the main lanes as to provide very little gap to observe cars coming onto the onramp.

It's hard to know even where to begin with improving these. A few thoughts include...

* Setting them at least 50m back from the road, so it's much clearer when cars are coming up the lane.
* Widening them into a proper path colocated with the sidewalk, to provide more room to slow down, stop, and turn.

But really, neither of these address the *actual* problem here. The problem is of speeding cars approaching a highway onramp at 60+km/h, without an approach lane, not signalling, and thus forcing a wait for a significant gap. Like most problems related to bikes-on-roads, the problem *should* be solved by modifications to driver behaviour and road design, not adding more inconveniences for cyclists. Here's how I'd design these:

![My Much Better Bike Crossing](improvedbikecrossing.png)

If you don't see why this is lightyears better, I don't know what to say.

## Actually Improving Bike Infrastructure

OK, enough whinging. What should be done to actually *improve* the bike infrastructure in this city? It's really simple.

* Fix the shitty bike paths! Huge numbers of the bike paths are in disarray as outlined above. Repave them, now. Not "soon", because "soon" was literally 20 years ago. There is already a significant network of paths in the city, so improve them to help encourage cycling trips where possible.

* Add more bike paths. Instead of futzing around with bike lanes, widen the sidewalks and convert them (partially or fully) to multi-use paths. Do this on every major road; most have plenty of space.

* Build better crossings. Slow down traffic at dangerous crossings, add approach lanes, and give bicyclists more room to maneuver.

* Add more connecting paths through residential areas, and between the areas of the city. Specifically, I mean tunnels under the railway line(s) and across the highway, to avoid cyclists (and pedestrians!) from having to take the obnoxious concrete jungles that are the current highway overpasses. Just two would be a huge boon to the connectivity of the city.

And that's the end of my rant. Hopefully I've educated someone on the pitfalls of the current designs and "ideas", and can offer some more obvious solutions.
